@@ -1,4 +1,4 @@
-import { MemberExpression, Node } from 'estree';
+import { Node } from 'estree';
 
 export default function isReference (node: Node, parent: Node): boolean {
 	if (node.type === 'MemberExpression') {
@@ -11,10 +11,8 @@ export default function isReference (node: Node, parent: Node): boolean {
 		// i.e. an arrow function expression like `a => a`
 		if (!parent) return true;
 
-		// TODO is this right?
-		if (parent.type === 'MemberExpression' || parent.type === 'MethodDefinition') {
-			return parent.computed || node === (<MemberExpression>parent).object;
-		}
+		if (parent.type === 'MemberExpression') return parent.computed || node === parent.object;
+		if (parent.type === 'MethodDefinition') return parent.computed;
 
 		// disregard the `bar` in `{ bar: foo }`, but keep it in `{ [bar]: foo }`
 		if (parent.type === 'Property') return parent.computed || node === parent.value;
@@ -22,6 +20,9 @@ export default function isReference (node: Node, parent: Node): boolean {
 		// disregard the `bar` in `export { foo as bar }`
 		if (parent.type === 'ExportSpecifier' && node !== parent.local) return false;
 
+		// disregard the foo in `foo: bar`
+		if (parent.type === 'LabeledStatement') return false;
+
 		return true;
 	}
 
